|
Rotate lower n bits
|
|
6
|
353
|
September 27, 2024
|
|
Unclear allocations with in-place mutating functions
|
|
14
|
414
|
September 26, 2024
|
|
FunctionWrapper allocating when called
|
|
10
|
431
|
September 26, 2024
|
|
Efficient iteration with fixed size array types without `@generated` functions
|
|
9
|
376
|
September 26, 2024
|
|
Block Diagonal Factorization Performance
|
|
1
|
316
|
September 25, 2024
|
|
Gradient-based adaptative sampling in NeuralPDE
|
|
1
|
92
|
September 25, 2024
|
|
Optimizing sums of products (dot products)
|
|
17
|
1076
|
September 24, 2024
|
|
Flux slows down by 10x when moving from local system to high performance cluster
|
|
10
|
488
|
September 24, 2024
|
|
Efficiently creating and updating a struct of SVectors
|
|
10
|
440
|
September 23, 2024
|
|
Quaternion to Euler angles
|
|
4
|
258
|
September 23, 2024
|
|
Pushing elements into a view
|
|
4
|
201
|
September 23, 2024
|
|
Julian way to write this code
|
|
18
|
1267
|
September 22, 2024
|
|
Why fft with MEASURE plan 10x slower than calling fft directly with CUDA.CUFFT?
|
|
7
|
324
|
September 22, 2024
|
|
Why does the speed of Julia in AOT compilation differ from UX4?
|
|
12
|
1069
|
September 21, 2024
|
|
Logical "and", &&, and mapreduce
|
|
8
|
340
|
September 21, 2024
|
|
Distributed computing over SLURM array
|
|
11
|
658
|
September 20, 2024
|
|
Tidiest way to reuse variables inside a function to reduce gc time
|
|
8
|
451
|
September 18, 2024
|
|
Different times with @elapsed, @time and @benchmark
|
|
3
|
704
|
September 17, 2024
|
|
Several questions about time evaluation with @time
|
|
7
|
305
|
September 16, 2024
|
|
Module parameters and run-time efficiency
|
|
3
|
158
|
September 17, 2024
|
|
Time integration in OrdinaryDiffEq.jl in Julia is slower than calling it from Python
|
|
12
|
564
|
September 16, 2024
|
|
Nested for loops vs Iterators.product performance
|
|
16
|
573
|
September 16, 2024
|
|
Using Symbolic simplification in DataFramesMeta macros
|
|
8
|
247
|
September 15, 2024
|
|
Performance of loop over multi-dimensional array limited by getindex
|
|
6
|
203
|
September 15, 2024
|
|
Fill SVector with uniformly sampled Float32 values
|
|
5
|
189
|
September 14, 2024
|
|
A lot of memory only loading modules!
|
|
8
|
467
|
September 14, 2024
|
|
Maximizing Input File Read Performance
|
|
7
|
409
|
September 13, 2024
|
|
Allocation-free weighted samples
|
|
12
|
515
|
September 12, 2024
|
|
Optimising voronoi computation
|
|
4
|
227
|
September 12, 2024
|
|
Improving GPU performance for symbolic regression
|
|
14
|
1459
|
September 12, 2024
|